@@ -1,5 +1,6 @@
 from password_strength import PasswordPolicy
 from password_strength import PasswordStats
+from ..log import log
 
 
 def is_strong_password(password: str):
@@ -16,7 +17,7 @@ def is_strong_password(password: str):
 def g_password_strength(password: str):
     # 0.66 will be a very good indication of a good password.
     # need a password that scores at least 0.5 with its strength
-    return PasswordStats(password).strength()
+    return PasswordStats(password).strength() if password else 0
 
 
 # policy = PasswordPolicy.from_names(
@@ -37,5 +38,8 @@ def hash_password(password: str):
 
 
 def verify_password(plain_password, hashed_password):
-    pwd_context = CryptContext(schemes=["bcrypt"], deprecated="auto")
-    return pwd_context.verify(plain_password, hashed_password)
+    try:
+        pwd_context = CryptContext(schemes=["bcrypt"], deprecated="auto")
+        return pwd_context.verify(plain_password, hashed_password)
+    except Exception as e:
+        log.exception(e)
