@@ -5,5 +5,5 @@ from .handler import add_start_event, add_stop_event
 from .response import resp, RespBase, RespStr, RespInt, RespDict, RespList, RespFloat
 from .router import r_home, r_upload_image, r_demo_resp
 from .error import abort_if, ValidationErrorMessage
-from .common import get_new_id, common_page_args, check_reset_key
+from .common import get_new_id, common_page_args, check_reset_key, generate_user_token
 from .model import ModelDict, ModelList, PageArgs, ModelKV, OnlyID, EnumYesNo
