@@ -30,7 +30,7 @@ async def generate_user_token(username, prefix='z'):
     db = conn()
     env = get_env()
     token = g_random_str(f'{prefix}_{username}', 128)
-    for key in db.keys(f'{prefix}_{username}_'):  # del old token
-        db.delete(key)
+    # for key in db.keys(f'{prefix}_{username}_'):  # del old token
+    #     db.delete(key)
     db.setx(token, username, env.token_user_expire)
     return token
